# "OctoBase"

## The First Building Block For Any Python Project

### Including "[Rightdown](https://octoboxy.com/rightdown/)", a Markdown dialect

When this project officially launches we'll copy most important parts of the docs here.

Full docs will always be at:  https://octoboxy.com/octobase/
